# simple Wiki-like view-filter features

package Ewok::Filter::Wiki;

use Ewok::Filter qw(:register);
use strict;

# Register filters and pipelines with Ewok::Filter
BEGIN {
    register_filter(
        camel_links => \&camel_links,
    );
    register_pipeline(
        WikiText => [qw(
            html_heading_anchors
            text_escape_html text_indented_sections text_headings text_hr 
            text_paragraph text_break_short_lines text_cleanup_pre_sections 
            text_paragraph_classes_styles text_bold_italics 
            text_links camel_links text_embperl_cleanup
            html_named_anchors html_headings html_contents
        )],
    );
}

sub link_if_exists
{
    my ($name, $arg) = @_;
    my $fs_dir = $arg->{fs_dir};
    my $web_dir = $arg->{web_dir};
    return -e "$fs_dir/$name.html" ? 
        qq(<a href="$name.html">$name</a>) : 
        qq($name<a href="/ewok/edit.html?mode=wiki&create=1&p=$web_dir/$name.html">?</a>);
}

# Markup CamelCase links
sub camel_links
{
    local $_ = shift;
    my $arg = shift;
    return $_ if defined $arg->{markup_links} && $arg->{markup_links} == 0;

    # Markup CamelCase link variants (min. 3 changes across lc/uc/digits)
    s#(?<!["\w])([A-Z]+[a-z]+[A-Z0-9]+\w*)#link_if_exists($1,$arg)#eg;
    s#(?<!["\w])([A-Z]+[0-9]+[A-Za-z]+\w*)#link_if_exists($1,$arg)#eg;
    s#(?<!["\w])([a-z]+[A-Z]+[a-z0-9]+\w*)#link_if_exists($1,$arg)#eg;
    s#(?<!["\w])([a-z]+[0-9]+[A-Za-z]+\w*)#link_if_exists($1,$arg)#eg;
    s#(?<!["\w])([0-9]+[A-Z]+[a-z0-9]+\w*)#link_if_exists($1,$arg)#eg;
    s#(?<!["\w])([0-9]+[a-z]+[A-Z0-9]+\w*)#link_if_exists($1,$arg)#eg;

    return $_;
}

1;

__END__

=head1 NAME

Ewok::Filter::Wiki - simple Wiki-like view filter features


=head1 SYNOPSIS

    use Ewok::Filter::Wiki;

    $page = Ewok::Filter::Wiki::filter($page);



=head1 DESCRIPTION

Ewok::Filter::Wiki is a simple view-filter providing additional 
Wiki-like features over the standard ewok text markup.


=head1 AUTHOR

Gavin Carr <gavin@openfusion.com.au>


=head1 COPYRIGHT

Copyright 2001-2003, Gavin Carr and Open Fusion Pty. Ltd. All Rights Reserved.

This program is free software. You may copy or redistribute it under the same 
terms as perl itself.

=cut


# arch-tag: c65a4150-9e79-4886-8b80-73c0f809a5cf
