#!/usr/bin/perl

use Getopt::Std;
use Test::More tests => 11;
use Ewok::TextMarkup qw(markup);
use Ewok::Filter qw(filter);
use Ewok::Filter::HTML;
use strict;

my %opts;
getopts('cdn:t',\%opts);
my $create = $opts{c};
my $diff = $opts{d};
my $n = $opts{n};
my $textmarkup = $opts{t};

die "no 'filter' directory" unless -d "filter";
die "no 'filter/out' directory" unless -d "filter/out";
chdir "filter" or die "cannot chdir to filter: $!";
my ($in, $out, $ans);
for my $test (<*html>) {
  open INPUT, "<", $test or die "open of 'filter/$test' failed: $!";
  {
    local $/ = undef;
    $in = <INPUT>;
  }
  close INPUT; 
  if ($textmarkup) {
    $out = markup(input => $in);
  }
  else {
    $out = filter($in);
  }

  if ($create) {
    print "... creating filter/out/$test\n";
    open OUTPUT, ">", "out/$test" or die "open of 'filter/out/$test' for write failed: $!";
    print OUTPUT $out;
    close OUTPUT;
  }
  else {
    open ANS, "<", "out/$test" or die "open of 'filter/out/$test' failed: $!";
    {
      local $/ = undef;
      $ans = <ANS>;
    }
    close OUTPUT; 
    ok($out eq $ans, $test);
    if ($diff && $out ne $ans) {
        open DIFF, "|diff - out/$test" or die "open diff failed: $!";
        print DIFF $out;
        close DIFF;
    }
  }
}

